############
Contributors
############

Here is an alphabetically-ordered list of the people who
contributed to this software in one way or another.

* Andreas Motl <andreas.motl@panodata.org>
* David Roet <https://en.vmm.be/>
* Matthias Mehldau <matthias.mehldau@panodata.org>
* Olav Peeters <https://en.vmm.be/>
* Richard Pobering <richard.pobering@panodata.org>

Thanks a bunch!


****************
Acknowledgements
****************
This program would not have been possible without all the amazing work
people are doing on the foundation infrastructure the software is leveraging.

Many people have been involved creating the software components this software
is built upon like InfluxDB, Grafana, Python and all the associated modules
around them.

Standing on the shoulders of giants. Thank you so much, you know who you are.
